/*
 * Home Health Grouper
 * Developer for the Center for Medicare and Medicaid Services CMS
 * by 3M Health Information Systems  for CMS Home Health.
 *
 * All code is provided as is.
 */
package com.mmm.cms.homehealth.io;


/**
 * This class reads OASIS records that were originally OASIS C 2.00 at 1449 characters
 * but incorrectly converted to extend C at 3256 character, but did not change the
 * version number, so the version number is "02.00" or "2.00"
 * 
 * @author 3M HIS
 */
public class Oasis_C_RecordUtil_v2_00a extends Oasis_C_RecordUtil_v2_10 {

    @Override
    public boolean isRecordConvertable(String record) {
        boolean convertable = false;

        if (record.length() >= Oasis_C_RecordUtil_v2_10.OASIS_C_FLAT_RECORD_LENGTH) {
            String infoCompleteDate;
            final char specVersionCD[] = new char[10];

            record.getChars(24, 34, specVersionCD, 0);
            infoCompleteDate = record.substring(434, 442);

            // make sure the CD1 is C and the year is 2014 or greater
            convertable = ((specVersionCD[0] == '0' && specVersionCD[1] == '2')
                    || (specVersionCD[0] == '2' && specVersionCD[1] == '.' && specVersionCD[2] == '0'))
                    && dateRanger.isDateWithinRange(infoCompleteDate);
        }

        return convertable;
    }
    
}
